<TS language="ca_ES" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Sobre Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Crea una nova adreça</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copia l'adreça seleccionada al porta-retalls del sistema</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Mostra el códi &amp;QR</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Signar un missatge per demostrar que és propietari d'una adreça Gridcoin</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Signar &amp;Message</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Comproveu el missatge per assegurar-se que es va signar amb una adreça Gridcoin especificada.</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verificar el missatge</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Elimina l'adreça sel·leccionada actualment de la llista</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Llibreta d'adreces</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Aquestes són les teves adreces de Gridcoin per rebre els pagaments. És possible que vulgueu donar una diferent a cada remitent per a poder realitzar un seguiment de qui li está pagant.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copia l'eti&amp;queta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edita</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Exportar dades de la llibreta d'adreces </translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Error a l'exportar</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>No s'ha pogut escriure al fitxer %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreça</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sense etiqueta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Diàleg de contrasenya</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Introduïu una contrasenya</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova contrasenya</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repetiu la nova contrasenya</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Serveix per desactivar l'enviament trivial de diners quan el compte del sistema operatiu ha estat compromès. No ofereix seguretat real.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Només per a fer "stake"</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Introduïu la contrasenya nova al moneder.&lt;br/&gt;Utilitzeu una contrasenya de &lt;b&gt;deu o més caràcters aleatoris&lt;/b&gt;, o &lt;b&gt;vuit o més paraules&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Encripta el moneder</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Aquesta operació requereix la contrasenya del moneder per a desbloquejar-lo.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloqueja el moneder</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Canvia la contrasenya</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Introdueixi tant l'antiga com la nova contrasenya de moneder.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirma l'encriptació del moneder</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Avís: Si xifra el seu moneder i perd la contrasenya, podrà &lt;b&gt; PERDRE TOTES LES SEVES MONEDES &lt;/ b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Esteu segur que voleu encriptar el vostre moneder?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Moneder encriptat</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin tancarà ara per acabar el procés de xifrat. Recordeu que l'encriptació del seu moneder no pot protegir completament les seves monedes de ser robades pel malware que pugui infectar al seu equip.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>IMPORTANT: Tota copia de seguretat que hàgiu realitzat hauria de ser reemplaçada pel, recentment generat, fitxer encriptat del moneder. Per motius de seguretat, les còpies de seguretat anteriors del fitxer de moneder no encriptat esdevindran inusables tan aviat com començar a utilitzar el nou moneder encriptat.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>L'encriptació del moneder ha fallat</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>L'encriptació del moneder ha fallat per un error intern. El moneder no ha estat encriptat.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Les contrasenyes introduïdes no coincideixen.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>El desbloqueig del moneder ha fallat</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La contrasenya introduïda per a desencriptar el moneder és incorrecta.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>La contrasenya del moneder ha estat modificada correctament.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Avís: Les lletres majúscules estan activades!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
        <translation>S'ha produït un error fatal. Gridcoin ja no pot continuar de forma segura i es tancarà.</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Moneder</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Panorama general</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Mostra el panorama general del moneder</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Envia</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Enviar monedes a una adreça Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Rep</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Mostra la llista d'adreces per rebre pagaments</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Cerca a l'historial de transaccions</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Edició de la llista d'adreces i etiquetes emmagatzemades</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>S&amp;urt</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Surt de l'aplicació</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;Sobre Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Mostra informació sobre Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opcions...</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Modificar les opcions de configuració per a Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Mostra / Amaga</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Encripta el moneder...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Canvia la contrasenya...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Canvia la contrasenya d'encriptació del moneder</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>&amp;Desbloquejar moneder</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloquejar el moneder</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Bloquejar moneder</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Bloquejar moneder</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Signa el &amp;missatge...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifica el missatge...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Exportar...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exportar les dades de la pestanya actual a un arxiu</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Finestra de depuració</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Obre la consola de diagnòstic i depuració</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuració</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Client Gridcoin</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Al dia</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>S'està posant al dia ...</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>El darrer bloc rebut s'ha generat %1.</translation>
    </message>
    <message>
        <source>This transaction is over the size limit.  You can still send it for a fee of %1, which goes to the nodes that process your transaction and helps to support the network.  Do you want to pay the fee?</source>
        <translation>Aquesta transacció es troba sobre el límit de mida. Encara pot enviar-la amb una comisió de %1, aquesta va als nodes que processen la seva transacció i ajuda a mantenir la xarxa. Vol pagar la quota?</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>Confirmeu comisió</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transacció enviada</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transacció entrant</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Manejant URI</translation>
    </message>
    <message>
        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
        <translation>l'URI no es pot analitzar! Això pot ser causat per una adreça Gridcoin no vàlida o paràmetres URI malformats.</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>El moneder està &lt;b&gt;encriptat&lt;/b&gt; i actualment &lt;b&gt;bloquejat&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Realitzar còpia de seguretat del moneder</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Dades del moneder (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Còpia de seguretat fallida</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to the new location.</source>
        <translation>Hi ha un error al tractar de salvar les dades del seu moneder a la nova ubicació.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Alerta de xarxa</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Quantitat:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Import:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Comissió:</translation>
    </message>
    <message>
        <source>Coin Control</source>
        <translation>Opcions del control de monedes</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Sortida baixa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Comissió posterior:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Canvi:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Confirmacions</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmat</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreça</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copia l'adreça</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copia l'etiqueta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia l'import</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copia l'ID de transacció</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copia la quantitat</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copia la comissió</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copia la comissió posterior</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copia els bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copiar sortida baixa</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copia el canvi</translation>
    </message>
    <message>
        <source>DUST</source>
        <translation>POLS</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>sí</translation>
    </message>
    <message>
        <source>This label turns red, if the transaction size is bigger than 10000 bytes.

 This means a fee of at least %1 per kb is required.

 Can vary +/- 1 Byte per input.</source>
        <translation>Aquesta etiqueta es tornarà vermell, si la mida de la transacció és més gran que 10000 bytes.

En aquest cas es requereix una comisió d'almenys el %1 per kb. 

Pot variar + / - 1 Byte per entrada.</translation>
    </message>
    <message>
        <source>This label turns red, if any recipient receives an amount smaller than %1.

 This means a fee of at least %2 is required. 

 Amounts below 0.546 times the minimum relay fee are shown as DUST.</source>
        <translation>Aquesta etiqueta es torna vermella, si qualsevol beneficiari rep una quantitat inferior a %1.

En aquest cas es requereix una comisió d'almenys %2.

Les quantitats inferiors a 0.546 vegades la quota mínima del relé es mostren com a POLS.</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>Aquesta etiqueta es torna vermella, si el canvi és menor que %1.

En aquest cas es requereix una comisió d'almenys %2.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sense etiqueta)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>canvia de %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(canvia)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Edita l'adreça</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiqueta</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>L'etiqueta associada amb aquesta entrada de la llibreta d'adreces</translation>
    </message>
    <message>
        <source>The address associated with this address book entry. This can only be modified for sending addresses.</source>
        <translation>La direcció associada amb aquesta entrada de la llibreta d'adreces. Només pot ser modificada per a l'enviament d'adreces.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adreça</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nova adreça de recepció</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nova adreça d'enviament</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Edita l'adreça de recepció</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Edita l'adreça d'enviament</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>La direcció introduïda "%1" no és una adreça Gridcoin vàlida.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>L'adreça introduïda «%1» ja és present a la llibreta d'adreces.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>No s'ha pogut desbloquejar el moneder.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Ha fallat la generació d'una clau nova.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>versió</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Ús:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>Opcions de la línia d'ordres</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Principal</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Xarxa</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Port obert amb &amp;UPnP</translation>
    </message>
    <message>
        <source>Automatically start Gridcoin after logging in to the system.</source>
        <translation>Inicia automàticament Gridcoin després d'entrar en el sistema.</translation>
    </message>
    <message>
        <source>&amp;Start Gridcoin on system login</source>
        <translation>&amp;Iniciar Gridcoin amb l'inici de sessió</translation>
    </message>
    <message>
        <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Obrir automàticament el port de client Gridcoin en el router. Això només funciona quan el router és compatible amb UPnP i està habilitat.</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>Adreça IP del servidor proxy (per exemple, 127.0.0.1)</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Port del proxy (per exemple 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimitza en comptes de sortir de la aplicació al tancar la finestra. Quan aquesta opció està activa, la aplicació només es tancarà al seleccionar Sortir al menú.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting Gridcoin.</source>
        <translation>L'idioma de la interfície d'usuari es pot configurar aquí. Aquesta configuració s'aplicarà després de reiniciar Gridcoin.</translation>
    </message>
    <message>
        <source>Whether to show Gridcoin addresses in the transaction list or not.</source>
        <translation>Per mostrar Gridcoin adreces a la llista de transaccions o no.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Mostrar adreces al llistat de transaccions</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Finestra</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Aplicar</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Mostra només la icona de la barra en minimitzar la finestra.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimitza a la barra d'aplicacions en comptes de la barra de tasques</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimitza en tancar</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Pantalla</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Llengua de la interfície d'usuari:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unitats per mostrar els imports en:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Selecciona la unitat de subdivisió per defecte per mostrar en la interfície quan s'envien monedes.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;D'acord</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel·la</translation>
    </message>
    <message>
        <source>default</source>
        <translation>Per defecte</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>Aquesta configuració s'aplicarà després de reiniciar Gridcoin.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>L'adreça proxy introduïda és invalida.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Disponible:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>El balanç que podeu gastar actualment</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Immadur:</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Gridcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>La informació mostrada pot estar fora de data. El seu moneder es sincronitza automàticament amb la xarxa Gridcoin després d'establir una connexió, però aquest procés no s'ha completat encara.</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the current balance</source>
        <translation>Total de transaccions que encara no s'han confirmat, i encara no compten per al balanç actual</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>El balanç total actual</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>QR Code Dialog</source>
        <translation>Diàleg de codi QR</translation>
    </message>
    <message>
        <source>Request Payment</source>
        <translation>Sol·licitud de pagament</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Etiqueta:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Missatge:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Quantitat:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Desa com ...</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Error codificant la URI en un codi QR.</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>La quantitat introduïda no és vàlida, comproveu-ho si us plau.</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>URI resultant massa llarga, intenta reduir el text per a la etiqueta / missatge</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Desar codi QR</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Versió del client</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informació</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>&amp;Temps d'inici</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Nombre de connexions</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Cadena de blocs</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Nombre de blocs actuals</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Últim temps de bloc</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Obre</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>Nete&amp;ja</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Consola</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>Trà&amp;nsit de la xarxa</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Dins:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Fora:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Fitxer de registre de depuració</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Neteja la consola</translation>
    </message>
    <message>
        <source>On testnet</source>
        <translation>A testnet</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Total estimat de blocs</translation>
    </message>
    <message>
        <source>Open the Gridcoin debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>Obriu el fitxer de registre de depuració Gridcoin des del directori de dades actual. Això pot trigar uns segons en els arxius de registre de grans dimensions.</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Opcions de la línia d'ordres</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>&amp;Mostra</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nom del client</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Utilitza les fletxes d'amunt i avall per navegar per l'historial, i &lt;b&gt;Ctrl-L&lt;\b&gt; per netejar la pantalla.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Escriviu &lt;b&gt;help&lt;\b&gt; per a obtenir un llistat de les ordres disponibles.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Envia monedes</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Entrades...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>seleccionat automàticament</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fons insuficients!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Quantitat:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Import:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Comissió:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Sortida baixa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Comissió posterior:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Canvi</translation>
    </message>
    <message>
        <source>custom change address</source>
        <translation>Adreça de canvi pròpia</translation>
    </message>
    <message>
        <source>Remove all transaction fields</source>
        <translation>Traieu tots els camps de transacció</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Envia a múltiples destinataris al mateix temps</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Afegeix &amp;destinatari</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Neteja-ho &amp;tot</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirma l'acció d'enviament</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>E&amp;nvia</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copia la quantitat</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia l'import</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copia la comissió</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copia la comissió posterior</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copia els bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copiar sortida baixa</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copia el canvi</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; to %2 (%3)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; a %2 (%3)</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirma l'enviament de monedes</translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>Esteu segur que voleu enviar %1?</translation>
    </message>
    <message>
        <source> and </source>
        <translation>i</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>L'adreça remetent no és vàlida, si us plau comprovi-la.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>L'import a pagar ha de ser major que 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>L'import supera el vostre balanç.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>El total excedeix el vostre balanç quan s'afegeix la comissió a la transacció %1.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>S'ha trobat una adreça duplicada, tan sols es pot enviar a cada adreça un cop per ordre de enviament.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>Error: La creació de transacció ha fallat.</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Error: La transacció ha sigut rebutjada. Això pot passar si algunes de les monedes al moneder ja s'han gastat, per exemple, si vostè utilitza una còpia del wallet.dat i les monedes han estat gastades a la cópia pero no s'han marcat com a gastades aqui.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sense etiqueta)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>ADVERTÈNCIA: Direcció Gridcoin invàlida</translation>
    </message>
    <message>
        <source>WARNING: unknown change address</source>
        <translation>ADVERTÈNCIA: direcció de canvi desconeguda</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Q&amp;uantitat:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Paga &amp;a:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Missatge:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta:</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alta+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Enganxar adreça del porta-retalls</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>Trieu la direcció de la llibreta d'adreces</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>Eliminar aquest destinatari</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Introduïu una etiqueta per a aquesta adreça per afegir-la a la llibreta d'adreces</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Signatures - Signa / verifica un missatge</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Signa el missatge</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Pots signar missatges amb la teva adreça per provar que són teus. Sigues cautelòs al signar qualsevol cosa, ja que els atacs phising poden intentar confondre't per a que els hi signis amb la teva identitat. Tan sols signa als documents completament detallats amb els que hi estàs d'acord.</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Trieu una adreça de la llibreta d'adreces</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alta+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Enganxar adreça del porta-retalls</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Introduïu aquí el missatge que voleu signar</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copia la signatura actual al porta-retalls del sistema</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Gridcoin address</source>
        <translation>Signar un missatge per demostrar que és propietari d'aquesta adreça Gridcoin</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Signa el &amp;missatge</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Neteja tots els camps de clau</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Neteja-ho &amp;tot</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifica el missatge</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Introdueixi l'adreça signant, missatge (assegura't que copies salts de línia, espais, tabuladors, etc excactament tot el text) i la signatura a sota per verificar el missatge. Per evitar ser enganyat per un atac home-entre-mig, vés amb compte de no llegir més en la signatura del que hi ha al missatge signat mateix.</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Gridcoin address</source>
        <translation>Comproveu el missatge per assegurar-se que es va signar amb l'adreça Gridcoin especificada.</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Neteja tots els camps de verificació de missatge</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Feu clic a «Signa el missatge» per a generar una signatura</translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>Introduïu la signatura Gridcoin</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>L'adreça introduïda no és vàlida.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Comproveu l'adreça i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>L'adreça introduïda no referencia a cap clau.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>El desbloqueig del moneder ha estat cancelat.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>La clau privada per a la adreça introduïda no està disponible.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>La signatura del missatge ha fallat.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Missatge signat.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>La signatura no s'ha pogut descodificar.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Comproveu la signatura i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>La signatura no coincideix amb el resum del missatge.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Ha fallat la verificació del missatge.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Missatge verificat.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Obert fins %1</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>conflicte</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/fora de línia</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/sense confirmar</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 confirmacions</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, encara no ha estat emès correctement</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Font</translation>
    </message>
    <message>
        <source>From</source>
        <translation>De</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconegut</translation>
    </message>
    <message>
        <source>To</source>
        <translation>A</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>adreça pròpia</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etiqueta</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Crèdit</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>no acceptat</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Dèbit</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Comissió de transacció</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Import net</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Missatge</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentari</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>true</source>
        <translation>cert</translation>
    </message>
    <message>
        <source>false</source>
        <translation>fals</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Detall de la transacció</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Aquest panell mostra una descripció detallada de la transacció</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Direcció</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantitat</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Obert fins %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Fora de línia</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Sense confirmar</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confirmat (%1 confirmacions)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>En conflicte</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generat però no acceptat</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Rebuda amb</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Rebuda de</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviada a</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pagament a un mateix</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Estat de la transacció. Desplaceu-vos sobre aquest camp per mostrar el nombre de confirmacions.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Data i hora en que la transacció va ser rebuda.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipus de transacció.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Adreça del destinatari de la transacció.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Import extret o afegit del balanç.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Avui</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Aquesta setmana</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Aquest mes</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>El mes passat</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Enguany</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Rang...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Rebuda amb</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviada a</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>A un mateix</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minada</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altres</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Import mínim</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copia l'adreça</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copia l'etiqueta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia l'import</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copia l'ID de transacció</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Editar etiqueta</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Mostra detalls de la transacció</translation>
    </message>
    <message>
        <source>Export Transaction Data</source>
        <translation>Exportació de dades de transaccions</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmat</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreça</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Quantitat</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Error a l'exportar</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>No s'ha pogut escriure al fitxer %1.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Rang:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>a</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Enviant...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Ha sorgit un error al configurar el port RPC %u escoltant a IPv6, retrocedint a IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Ha sorgit un error al configurar el port RPC %u escoltant a IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Ús:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Llista d'ordres</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Obtenir ajuda per a un ordre.</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Advertència: el -paytxfee és molt elevat! Aquesta és la comissió de transacció que pagaràs quan enviis una transacció.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Advertència: L'arxiu wallet.dat és corrupte, dades rescatades! L'arxiu wallet.dat original ha estat desat com wallet.{estampa_temporal}.bak al directori %s; si el teu balanç o transaccions son incorrectes hauries de restaurar-lo de un backup.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Advertència: Error llegint l'arxiu wallet.dat!! Totes les claus es llegeixen correctament, però hi ha dades de transaccions o entrades del llibre d'adreces absents o bé son incorrectes.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>Error: La creació de transacció ha fallat.</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected.  This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Error: La transacció ha sigut rebutjada. Això pot passar si algunes de les monedes al moneder ja s'han gastat, per exemple, si vostè utilitza una còpia del wallet.dat i les monedes han estat gastades a la cópia pero no s'han marcat com a gastades aqui.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Ha fallat escoltar a qualsevol port. Feu servir -listen=0 si voleu fer això.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Utilitza la opció %s</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Has de configurar el rpcpassword=&lt;password&gt; a l'arxiu de configuració:\n %s\n Si l'arxiu no existeix, crea'l amb els permís owner-readable-only.</translation>
    </message>
    <message>
        <source>Gridcoin version</source>
        <translation>versió Gridcoin</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Quantitat invalida per a -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>Quantitat invalida per a -mininput=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>El moneder %s resideix fora del directori de dades %s.</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Comprovant la integritat de la base de dades ...</translation>
    </message>
    <message>
        <source>Error initializing database environment %s! To recover, BACKUP THAT DIRECTORY, then remove everything from it except for wallet.dat.</source>
        <translation>Error en inicialitzar l'entorn de base de dades %s! Per recuperar, FACI UNA COPIA DE SEGURETAT D'AQUEST DIRECTORI, a continuació, retiri tot d'ella excepte l'arxiu wallet.dat.</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>L'arxiu wallet.data és corrupte, el rescat de les dades ha fallat</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Adreça -proxy invalida: '%s'</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>Adreça -tor invalida: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>No es pot resoldre l'adreça -bind: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>No es pot resoldre l'adreça -externalip: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>Quantitat invalida per a -reservebalance=&lt;amount&gt;</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>Error carregant blkindex.dat</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Error carregant wallet.dat: Moneder corrupte</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>Error en carregar wallet.dat: El moneder requereix la versió més recent de Gridcoin</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>El moneder necessita ser reescrita: reiniciar Gridcoin per completar</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Error carregant wallet.dat</translation>
    </message>
    <message>
        <source>Importing bootstrap blockchain data file.</source>
        <translation>Important fitxer de dades d'arrencada de la cadena de blocs</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>S'estan carregant les adreces...</translation>
    </message>
    <message>
        <source>Error: could not start node</source>
        <translation>Error: no s'ha pogut iniciar el node</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. Gridcoin is probably already running.</source>
        <translation>No es pot enllaçar a %s en aquest equip. Gridcoin probablement ja estigui en funcionament.</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Impossible d'unir %s a aquest ordinador (s'ha retornat l'error %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet locked, unable to create transaction  </source>
        <translation>Error: Moneder bloquejat, no es pot de crear la transacció</translation>
    </message>
    <message>
        <source>Error: Wallet unlocked for staking only, unable to create transaction.</source>
        <translation>Error: Cartera bloquejada nomès per a fer "stake", no es pot de crear la transacció</translation>
    </message>
    <message>
        <source>Error: This transaction requires a transaction fee of at least %s because of its amount, complexity, or use of recently received funds  </source>
        <translation>Error: Aquesta transacció requereix una comisió d'almenys %s degut a la seva quantitat, complexitat, o l'ús dels fons rebuts recentment</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Enviant...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Quanitat invalida</translation>
    </message>
    <message>
        <source>Warning: Please check that your computer's date and time are correct! If your clock is wrong Gridcoin will not work properly.</source>
        <translation>Avís: Comproveu que la data i hora de l'equip siguin correctes! Si el seu rellotge és erroni Gridcoin no funcionarà correctament.</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Avís: L'espai en disc és baix!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Xarxa desconeguda especificada a -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Balanç insuficient</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>S'està carregant l'índex de blocs...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>S'està carregant el moneder...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>No es pot escriure l'adreça per defecte</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>S'està reescanejant...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Ha acabat la càrrega</translation>
    </message>
    </context>
</TS>